@@ -6,5 +6,8 @@ from .embed import *
 from .user import *
 from .channel import *
 from .guild import *
+from .author import *
+from .message import *
+from .exceptions import *
 
-__version__ = "0.2.8"
\ No newline at end of file
+__version__ = "3.0.3"
